@@ -5,9 +5,10 @@ from nctoolkit.mp_utils import get_type
 from nctoolkit.matchpoint import open_matchpoint
 
 
-def match_points(ds=None, df = None, variables=None, depths = None, nan=None, top = False, tmean = False, regrid = "bil"):
+def match_points(ds=None, df = None, variables=None, depths = None, nan=None, top = False, tmean = False, regrid = "bil", max_extrap = 5):
     """
     Match netCDF data to a spatiotemporal points dataframe
+
     Parameters
     -------------
     ds: nctoolkit dataset or str/list of file paths
@@ -34,6 +35,8 @@ def match_points(ds=None, df = None, variables=None, depths = None, nan=None, to
     regrid: str
         Regridding method. Defaults to "bil". Options available are those in nctoolkit regrid method.
         "nn" for nearest neighbour.
+    max_extrap: float
+        Maximum distance for vertical extrapolation of values 
 
     Returns
     ---------------
@@ -45,13 +48,14 @@ def match_points(ds=None, df = None, variables=None, depths = None, nan=None, to
 
     mp.add_data(x = ds, variables = variables, depths = depths, nan = nan, top = top)
     mp.add_points(df)
-    mp.matchup(tmean = tmean, regrid = regrid)
+    mp.matchup(tmean = tmean, regrid = regrid, max_extrap = max_extrap)
     return mp.values
 
 
 def add_data(self, x=None, variables=None, depths = None, nan=None, top = False):
     """
     Add dataset for matching
+
     Parameters
     -------------
     x: nctoolkit dataset or str/list of file paths
@@ -214,6 +218,7 @@ def add_data(self, x=None, variables=None, depths = None, nan=None, top = False)
 def add_depths(self, x=None):
     """
     Add depth
+
     Parameters
     -------------
     x:  nctoolkit dataset or list/iterable
@@ -240,6 +245,7 @@ def add_depths(self, x=None):
 def add_points(self, df=None):
     """
     Add point data
+
     Parameters
     -------------
     df: pandas dataframe containing the spatiotemporal points to match with.
