@@ -167,8 +167,10 @@ def vertical_mean(self, thickness=None, depth_range=None):
 
     self.run()
 
+    self1 = self.copy()
+
     if len(self) > 1:
-        raise ValueError("This only works with single file datasets currently")
+        warnings.warn("Vertical structure will be assumed to be the same for all files in the dataset")
 
     # Set up the thickness
 
@@ -180,11 +182,13 @@ def vertical_mean(self, thickness=None, depth_range=None):
             raise ValueError("Please provide a thickness dataset with 1 variable!")
         sorted = True
 
+    drop_this = None
     if sorted is False:
         if thickness in self.variables:
-            ds_thick = self.copy()
+            ds_thick = open_data(self[0]) 
             ds_thick.subset(variable=thickness)
             ds_thick.run()
+            drop_this = thickness
         else:
             ds_thick = open_data(thickness)
             if len(ds_thick.variables) != 1:
@@ -207,20 +211,28 @@ def vertical_mean(self, thickness=None, depth_range=None):
         ds_thick.assign(thickness=lambda x: x.depth - x.z_min, drop=True)
         ds_thick.assign(thickness=lambda x: x.thickness * (x.thickness > 0), drop=True)
 
-    self.subset(variables=self.contents.query("nlevels > 1").variable)
+    self1.subset(variables=self.contents.query("nlevels > 1").variable)
+    if drop_this is not None:
+        self1.drop(variables = drop_this)
 
-    self.multiply(ds_thick)
-    self.vertical_sum()
-    self.run()
+    self1.multiply(ds_thick)
+    self1.vertical_sum()
+    self1.run()
 
     ds_thick.vertical_sum()
-    self.divide(ds_thick)
+    self1.divide(ds_thick)
+    self1.run()
 
     del ds_thick
     if type(depth_range) is list:
         del ds_depth
 
 
+    self.current = self1.current
+    self.history = self1.history
+    self._hold_history = self1._hold_history
+
+
 def vertical_min(self):
     """
     Calculate the vertical minimum of variable values
@@ -299,6 +311,7 @@ def vertical_integration(self, thickness=None, depth_range=None):
         if depth_range[1] <= depth_range[0]:
             raise ValueError("Please provide a correctly ordered depth range")
 
+    drop_this = None
     if depth_range is not None:
         if type(depth_range) is not list:
             raise TypeError("Please provide a list for the depth range!")
@@ -310,10 +323,12 @@ def vertical_integration(self, thickness=None, depth_range=None):
     self.run()
 
     if len(self) > 1:
-        raise ValueError("This only works with single file datasets currently")
+        warnings.warn("Vertical integration will assume all files have the same structure")
 
     # Set up the thickness
 
+    self1 = self.copy()
+
     sorted = False
 
     if "api.DataSet" in str(type(thickness)):
@@ -324,9 +339,10 @@ def vertical_integration(self, thickness=None, depth_range=None):
 
     if sorted is False:
         if thickness in self.variables:
-            ds_thick = self.copy()
+            ds_thick = open_data(self1[0])
             ds_thick.subset(variable=thickness)
             ds_thick.run()
+            drop_this = thickness
         else:
             ds_thick = open_data(thickness)
             if len(ds_thick.variables) != 1:
@@ -349,15 +365,21 @@ def vertical_integration(self, thickness=None, depth_range=None):
         ds_thick.assign(thickness=lambda x: x.depth - x.z_min, drop=True)
         ds_thick.assign(thickness=lambda x: x.thickness * (x.thickness > 0), drop=True)
 
-    self.subset(variables=self.contents.query("nlevels > 1").variable)
+    self1.subset(variables=self1.contents.query("nlevels > 1").variable)
+    if drop_this is not None:
+        self1.drop(variables = drop_this)
 
-    self.multiply(ds_thick)
-    self.vertical_sum()
-    self.run()
+    self1.multiply(ds_thick)
+    self1.vertical_sum()
+    self1.run()
     del ds_thick
     if type(depth_range) is list:
         del ds_depth
 
+    self.current = self1.current
+    self.history = self1.history
+    self._hold_history = self1._hold_history
+
 
 def vertical_sum(self):
     """
@@ -430,7 +452,7 @@ def bottom_mask(self):
     var_use = data.contents.query("nlevels>1").variable[0]
     data.subset(variables=var_use)
     data.subset(timesteps=0)
-    data.set_missing([0, 0])
+    data.as_missing([0, 0])
     data.cdo_command(f"expr,'Wet={var_use}=={var_use}'")
     data.invert_levels()
     data.run()
@@ -441,7 +463,7 @@ def bottom_mask(self):
     bottom.invert_levels()
     bottom.rename({"Wet": "bottom"})
     bottom.set_longnames({"bottom": "Identifier for cell nearest seabed"})
-    bottom.set_missing([0, 0])
+    bottom.as_missing([0, 0])
     bottom.run()
 
     self.current = copy.deepcopy(bottom.current)
